/* -*- C++ -*-
 * LocalReplicaCatalog.cpp
 *
 * Copyright (c) 2002 CERN on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or 
 * http://www.edg.org/license.html
 * 
 * $Id: ReplicaLocationService.h,v 1.7 2003/09/18 23:37:43 rado Exp $
 *
 */


#ifndef ReplicaLocationService_H
#define ReplicaLocationService_H

#include "EdgReplicaLocationService/LocalReplicaCatalog.h"

#include <string>

namespace EdgReplicaLocationService
{

  /** A ReplicaLocationService stores mappings from Logical filenames to
   * Physical fileNames, along with attributes on those fileNames.  It also
   * provides indices for efficient location of the mappings.
   *
   * Currently we only provide a single catalog, a LocalReplicaCatalog, which
   * stores the LfnPfnMapping s as well as the attributes.
   */
  class ReplicaLocationService
  {
    public:

      /** Obtain the LocalReplicaCatalog at a given URL.
       * @param url the URL to look for the catalog
       * @param timeOut the timeout value, positive means seconds negative microseconds,
       *                default is 30 seconds
       * @return The catalog.
       * @throws NoSuchLocalReplicaCatalog if no catalog exists at that URL
       */
      static LocalReplicaCatalog*
      getLocalReplicaCatalog(const std::string& url,
                             int timeOut = 30);

#ifdef WITH_WP2_SECURITY
      /* Decls of two factory methods for adding security parameters */
      static LocalReplicaCatalog*
      getLocalReplicaCatalog(const std::string& url,
                             char *passphrase,
                             char *credentials,
                             char *cacertdir,
                             char *rseedfile,
                             int timeOut = 30);

      static LocalReplicaCatalog*
      getLocalReplicaCatalog(const std::string& url,
                             char *passphrase,
                             char *credentials,
                             char *cacertdir,
                             char *rseedfile,
                             char *role,
                             char *policy,
                             char *defaultrole,
                             char *defaultpolicy,
                             int timeOut = 30);
#endif

  };
}

#endif

