/* -*- C++ -*- $Id: ReplicaMetadataCatalogFactory.h,v 1.4 2003/07/24 15:12:42 mika Exp $
 * LocalReplicaCatalog.cpp
 *
 * Copyright (c) 2002 CERN on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or 
 * http://www.edg.org/license.html
 * 
 */

#ifndef ReplicaMetadataCatalogFactory_H
#define ReplicaMetadataCatalogFactory_H 1

#include "EdgReplicaMetadataCatalog/ReplicaMetadataCatalog.h"

#include <string>

namespace EdgReplicaMetadataCatalog {

  /** A ReplicaMetadataCatalog stores mappings from Logical filenames to
   * Physical fileNames, along with attributes on those fileNames.  It also
   * provides indices for efficient location of the mappings.
   *
   */

  class ReplicaMetadataCatalogFactory {
  public:

    /** Obtain the ReplicaMetadataCatalog at a given URL.
     * @param url     the URL to look for the catalog
		 * @param timeOut the time-out value, default is 30s, if positive it means seconds,
		 *                if negative it means microseconds
     * @return The catalog.
     * @throws NoSuchMetadataCatalog if no catalog exists at that URL
     */
    static ReplicaMetadataCatalog* getReplicaMetadataCatalog(const std::string& url,
																														 int timeOut=30);

#ifdef WITH_WP2_SECURITY
    /* Decls of two factory methods for adding security parameters */
    static ReplicaMetadataCatalog* getReplicaMetadataCatalog(const std::string& url,
							     char *passphrase,
							     char *credentials,
							     char *cacertdir,
							     char *rseedfile,
							     int timeOut = 30);

    static ReplicaMetadataCatalog* getReplicaMetadataCatalog(const std::string& url,
							     char *passphrase,
							     char *credentials,
							     char *cacertdir,
							     char *rseedfile,
							     char *role,
							     char *policy,
							     char *defaultrole,
							     char *defaultpolicy,
							     int timeOut = 30);
#endif

  };
}; 

#endif // ReplicaMetadataCatalogFactory_H

