/* -*- C++ -*-
 * ReplicaOptimizationFactory.h
 *
 * Copyright (c) 2002 CERN on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or 
 * http://www.edg.org/license.html
 * 
 */


#ifndef ReplicaOptimizationFactory_H
#define ReplicaOptimizationFactory_H 1

#include "EdgReplicaOptimization/ReplicaOptimization.h"

#include <string>

namespace EdgReplicaOptimization {
  /** A ReplicaOptimization stores mappings from Logical filenames to
   * Physical fileNames, along with attributes on those fileNames.  It also
   * provides indices for efficient location of the mappings.
   *
   */

  class ReplicaOptimizationFactory {
  public:

    /** Obtain the ReplicaOptimization at a given URL.
     * @param url     the URL to look for the catalog
		 * @param timeOut the timeout after which gSOAP gives up and
		 *                returns control back to client app, default is 30 seconds,
		 *                if positive means seconds and if negative means microseconds
     * @return The catalog.
     * @throws NoSuchMetadataCatalog if no catalog exists at that URL
     */

    static
    ReplicaOptimization* getReplicaOptimization(const std::string& url,
						int timeOut=30
#ifdef WITH_WP2_SECURITY
						,char *passphrase = NULL,
						char *credentials = NULL,
						char *cacertdir = NULL,
						char *rseedfile = NULL,
						char *role = NULL,
						char *policy = NULL,
						char *defrole = NULL,
						char *defpolicy = NULL
#endif
						);
  };
}

#endif // OptimizationFactory_H

