/* -*- C++ -*-
 *
 * ReplicaOptimizationImpl.h
 *
 * Copyright (c) 2002 CERN on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or 
 * http://www.edg.org/license.html
 *
 * $Id: ReplicaOptimizationImpl.h,v 1.17 2004/05/07 14:46:42 jamesc Exp $
 */


#ifndef ReplicaOptimizationImpl_H
#define ReplicaOptimizationImpl_H 1

/**
 * @author <a href="mailto:Kurt.Stockinger@cern.ch">Kurt Stockinger</a>
 * @author <a href="mailto:Peter.Kunszt@cern.ch">Peter Kunszt</a>
 * @author <a href="mailto:Radovan.Chytracek@cern.ch">Radovan Chytracek</a>
 */

#include <string>

#include "EdgReplicaOptimization/ReplicaOptimization.h"

struct soap;
struct SOAP_ENV_Fault;

namespace EdgReplicaOptimization
{

  /** 
   * Implementation of getAccessCost() to assist Resource Broker in matchmaking
   */
  class ReplicaOptimizationImpl : public ReplicaOptimization
  {
    
  public:
                        
    /** 
     * create a new ReplicaOptimization object
     * @param url     the URL to look for the catalog
     * @param timeOut the timeout after which gSOAP gives up and
     *                returns control back to client app, default is 30 seconds,
     *                if positive means seconds and if negative means microseconds
     *                The rest are secure gSOAP parameters
     *                role = the role you want
     *                policy = the policy you want
     *                defrole = default role, don't leave empty if you have a role
     *                defpolicy = default policy, don't leave empty if you have a policy
     *                passphrase .. see gSoap docs
     *                credentials
     *                cacertdir
     *                rseedfile
     **/

    ReplicaOptimizationImpl(const std::string& url,
                            int timeOut=30
#ifdef WITH_WP2_SECURITY
                            ,char *passphrase = NULL,
                            char *credentials = NULL,
                            char *cacertdir = NULL,
                            char *rseedfile = NULL,
                            char *role = NULL,
                            char *policy = NULL,
                            char *defrole = NULL,
                            char *defpolicy = NULL
#endif
                            );

#ifdef WITH_WP2_SECURITY

    int addRoleAndPolicy(char *role,
                         char *policy,
                         char *defaultrole,
                         char *defaultpolicy);
      
    void clearRoleAndPolicy();

#endif
    /** Standard virtual destructor
     */
    virtual ~ReplicaOptimizationImpl();
                        
    virtual const std::string& getUrl() const;
                        
    virtual bool ping();
                        
    /** Return ROS server version as std::string
     * @throws CommunicationException in case of an unknown server error
     */
    virtual const std::string getVersion() const
      throw(CommunicationException);
                        
    /** Return ROS server interface version as std::string
     * @throws CommunicationException in case of an unknown server error
     */
    virtual const std::string getInterfaceVersion() const
      throw(CommunicationException);

    virtual void getAccessCost(ROSFiles_t                        &files, 
                               ROSComputingElements_t  &ce, 
                               Protocols_t             &protocol,
                               AccessCosts_t                 &accessCost);
                          
    virtual void
    getBestNetworkCost(ROSFile                &file,
                       std::string      &destinationSE,
                       BestNetworkCost  &networkCost );
                        
  private:
                        
    void
    dump_soap_error(int ret, const struct soap* const_soap) const;
                        
    void
    handleGenericFaults(int ret, const struct soap* soap) const;
                        
    const char* endpoint() const;
                        
    struct soap* soap() const;
                        
                        
    //
    // member variables
    //
    const std::string m_endpoint;
    struct soap*      m_soap;
                        
  };
}

#endif // ReplicaOptimizationImpl_H

