/* -*- C++ -*-
 *
 * ReplicationExceptions.h
 *
 * Copyright (c) 2002 CERN on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or 
 * http://www.edg.org/license.html
 * 
 */

#include <exception>
#include <string>

#ifndef ROSReplicationExceptions_H
#define ROSReplicationExceptions_H 1

/** 
 *
 * @author <a href="mailto:james.casey@cern.ch">James Casey</a>
 * @author <a href="mailto:Radovan.Chytracek@cern.ch">Radovan Chytracek</a>
 * @version $Id: ReplicationExceptions.h,v 1.2 2003/03/20 14:53:22 pkunszt Exp $
 */
namespace EdgReplicaOptimization {

  /**
   * A simple top-level exception class for Replication Exception.
   *
   */
  class ReplicationException : public std::exception {
    public:

    public:
      ReplicationException() throw() 
       : m_faultCode("FAULTABLE") {
      }
      ReplicationException(const std::string& what) throw() 
       : m_what (what), m_faultCode("INTERNAL") {
      }
      ReplicationException(const std::string& what,
			   const std::string& faultCode) throw() 
       : m_what (what), m_faultCode(faultCode) {
      }
    const std::string& faultCode() const throw() {
      return m_faultCode;
    }
      virtual const char* what () const throw() {
        return m_what.c_str ();
      }
      virtual ~ReplicationException() throw(){
      }

    private:
      std::string m_what;
      std::string m_faultCode;

  };


  class CommunicationException : public ReplicationException {
    public: 
      CommunicationException() 
      : ReplicationException() {
      }
      CommunicationException(const std::string& message) 
      : ReplicationException(message, "CONNECTION") {
      }
      virtual ~CommunicationException() throw(){
      }
  };

  /** A dispatch method for the soap faults that will throw the
   * appropriate language exception
   * @param fault fault string, as defined by the LRC SOAP API
   * @param detail fault specific detail information
   */
  void
    throwReplicationException(const std::string& fault,
	                            const std::string& detail);
}


#endif // ReplicationExceptions_H

